@@ -33,7 +33,11 @@ markdown_extra_tags = [
     'br',
     'pre',
     'div',
-    'span'
+    'span',
+    'table',
+    'tr',
+    'th',
+    'th'
 ]
 markdown_extra_attrs = {
     'img': ['src', 'alt'],
